aboutsummaryrefslogtreecommitdiffstats
path: root/includes/parser/ParserOutputFlags.php
diff options
context:
space:
mode:
Diffstat (limited to 'includes/parser/ParserOutputFlags.php')
-rw-r--r--includes/parser/ParserOutputFlags.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/includes/parser/ParserOutputFlags.php b/includes/parser/ParserOutputFlags.php
index 007083d589fb..efda54ccca66 100644
--- a/includes/parser/ParserOutputFlags.php
+++ b/includes/parser/ParserOutputFlags.php
@@ -94,9 +94,9 @@ class ParserOutputFlags {
// These flags are stored in the ParserOutput::$mFlags array
/**
* @var string Hide the table of contents in the skin?
*/
- public const HIDE_TOC = 'hide-toc';
+ public const SHOW_TOC = 'show-toc';
/**
* @var string Used to suppress language conversion in ToC contents.
@@ -166,7 +166,7 @@ class ParserOutputFlags {
self::NO_INDEX_POLICY,
self::NEW_SECTION,
self::HIDE_NEW_SECTION,
- self::HIDE_TOC,
+ self::SHOW_TOC,
self::PREVENT_CLICKJACKING,
self::VARY_REVISION,
self::VARY_REVISION_ID,
@@ -94,9 +94,9 @@ class ParserOutputFlags {
// These flags are stored in the ParserOutput::$mFlags array
/**
- * @var string Hide the table of contents in the skin?
+ * @var string Show the table of contents in the skin?
*/